==> ZenTaoALM.12.4.2.int.zip: zentaoalm/module/dev/lang/vi.php <==
<?php
$lang->dev->common     = 'Phát triển';
$lang->dev->api        = 'API';
$lang->dev->db         = 'Database';
$lang->dev->editor     = 'Editor';
$lang->dev->translate  = 'Translate';
$lang->dev->dbList     = 'Database';
$lang->dev->moduleList = 'Modules';
$lang->dev->params     = 'Thông số';
$lang->dev->type       = 'Loại';
$lang->dev->desc       = 'Mô tả';
$lang->dev->noParams   = 'Không có Parameters';
$lang->dev->post       = 'POST Parameter';

$lang->dev->paramRange    = 'Parameter Range: %s';
$lang->dev->paramDate     = 'Date format: YY-mm-dd, e.g 2019-01-01';
$lang->dev->paramColor    = 'Color format: #RGB, ví dụ:  #3da7f5';
$lang->dev->paramMailto   = "User account. Separate accounts by ','.";
$lang->dev->noteEditor    = "The editor is disabled for security reasons. To use this feature, please go to the official website to download and install the plugin of the <a href='https://www.zentao.pm/extension-viewExt-150.html' target='_blank'>editor</a>.";
$lang->dev->noteTranslate = "The translation is disabled for security reasons. To use this feature, please go to the official website to download and install the plugin of <a href='https://www.zentao.pm/extension-viewExt-151.html' target='_blank'>translation</a>.";

$lang->dev->fields = array();
$lang->dev->fields['id']     = 'ID';
$lang->dev->fields['name']   = 'Feild';
$lang->dev->fields['desc']   = 'Mô tả';
$lang->dev->fields['type']   = 'Loại';
$lang->dev->fields['length'] = 'Chiều dài';
$lang->dev->fields['null']   = 'Null';

$lang->dev->tableList = array();
$lang->dev->tableList['action']           = 'Hành động';
$lang->dev->tableList['bug']              = 'Bug';
$lang->dev->tableList['build']            = 'Bản dựng';
$lang->dev->tableList['burn']             = 'Burndown Chart';
$lang->dev->tableList['case']             = 'tình huống';
$lang->dev->tableList['casestep']         = 'Case bước';
$lang->dev->tableList['company']          = 'Doanh nghiệp';
$lang->dev->tableList['config']           = 'Cấu hình';
$lang->dev->tableList['custom']           = 'Tùy biến';
$lang->dev->tableList['dept']             = 'Phòng/Ban';
$lang->dev->tableList['doc']              = 'Tài liệu';
$lang->dev->tableList['doclib']           = 'Thư viện tài liệu';
$lang->dev->tableList['effort']           = 'Chấm công';
$lang->dev->tableList['extension']        = 'Extension';
$lang->dev->tableList['file']             = 'File';
$lang->dev->tableList['group']            = 'Nhóm';
$lang->dev->tableList['grouppriv']        = 'Phân quyền';
$lang->dev->tableList['history']          = 'Lịch sử';
$lang->dev->tableList['lang']             = 'Ngôn ngữ';
$lang->dev->tableList['module']           = 'Module';
$lang->dev->tableList['product']          = $lang->productCommon;
$lang->dev->tableList['productplan']      = 'Kế hoạch '.$lang->productCommon;
$lang->dev->tableList['project']          = $lang->projectCommon;
$lang->dev->tableList['projectproduct']   = $lang->projectCommon . $lang->productCommon;
$lang->dev->tableList['projectstory']     = $lang->projectCommon . 'Câu chuyện';
$lang->dev->tableList['release']          = 'Phát hành';
$lang->dev->tableList['story']            = 'Câu chuyện';
$lang->dev->tableList['storyspec']        = 'Mô tả câu chuyện';
$lang->dev->tableList['task']             = 'Nhiệm vụ';
$lang->dev->tableList['taskestimate']     = 'Dự tính';
$lang->dev->tableList['team']             = 'Đội nhóm';
$lang->dev->tableList['testresult']       = 'Test kết quả';
$lang->dev->tableList['testrun']          = 'Test Run';
$lang->dev->tableList['testtask']         = 'Yêu cầu Test';
$lang->dev->tableList['todo']             = 'Việc làm';
$lang->dev->tableList['user']             = 'Người dùng';
$lang->dev->tableList['usercontact']      = 'Người dùng Liên hệ';
$lang->dev->tableList['usergroup']        = 'Người dùng Group';
$lang->dev->tableList['userquery']        = 'Người dùng truy vấn';
$lang->dev->tableList['usertpl']          = 'Người dùng mẫu';
$lang->dev->tableList['admin']            = 'Quản trị';
$lang->dev->tableList['api']              = 'API';
$lang->dev->tableList['backup']           = 'Sao lưu';
$lang->dev->tableList['common']           = 'Common';
$lang->dev->tableList['convert']          = 'Chuyển đổi';
$lang->dev->tableList['dev']              = 'Phát triển';
$lang->dev->tableList['git']              = 'GIT';
$lang->dev->tableList['index']            = 'Trang chủ';
$lang->dev->tableList['install']          = 'Cài đặt';
$lang->dev->tableList['mail']             = 'Email';
$lang->dev->tableList['misc']             = 'Khác';
$lang->dev->tableList['my']               = 'Dashboard';
$lang->dev->tableList['qa']               = 'QA';
$lang->dev->tableList['report']           = 'Báo cáo';
$lang->dev->tableList['search']           = 'Tìm kiếm';
$lang->dev->tableList['sso']              = 'SSO';
$lang->dev->tableList['svn']              = 'SVN';
$lang->dev->tableList['testcase']         = 'tình huống';
$lang->dev->tableList['testreport']       = 'Test báo cáo';
$lang->dev->tableList['testsuite']        = 'Test Suite';
$lang->dev->tableList['caselib']          = 'Case Library';
$lang->dev->tableList['tree']             = 'Module Tree';
$lang->dev->tableList['upgrade']          = 'Cập nhật';
$lang->dev->tableList['cron']             = 'Cron';
$lang->dev->tableList['datatable']        = 'Dữ liệu bảng';
$lang->dev->tableList['block']            = 'Block';
$lang->dev->tableList['branch']           = 'Nhánh';
$lang->dev->tableList['doccontent']       = 'Doc Content';
$lang->dev->tableList['storystage']       = 'Giai đoạn câu chuyện';
$lang->dev->tableList['tutorial']         = 'Hướng dẫn';
$lang->dev->tableList['suitecase']        = 'Suite tình huống';
$lang->dev->tableList['score']            = 'Điểm';
$lang->dev->tableList['entry']            = 'Application';
$lang->dev->tableList['webhook']          = 'WebHook';
$lang->dev->tableList['log']              = 'Nhật ký';
$lang->dev->tableList['message']          = 'Tin nhắn';
$lang->dev->tableList['notify']           = 'Thông báo';
$lang->dev->tableList['userview']         = 'Người dùng Privilege';
$lang->dev->tableList['repo']             = 'Mã';
$lang->dev->tableList['repohistory']      = 'Repo History';
$lang->dev->tableList['repofiles']        = 'Repo Files';
$lang->dev->tableList['repobranch']       = 'Repo nhánh';
$lang->dev->tableList['ci']               = 'CI';
$lang->dev->tableList['compile']          = 'Compile';
$lang->dev->tableList['jenkins']          = 'Jenkins';
$lang->dev->tableList['job']              = 'Job';

$lang->dev->groupList['my']      = 'Dashboard';
$lang->dev->groupList['product'] = $lang->productCommon;
$lang->dev->groupList['project'] = $lang->projectCommon;
$lang->dev->groupList['qa']      = 'QA';
$lang->dev->groupList['doc']     = 'Tài liệu';
$lang->dev->groupList['report']  = 'Báo cáo';
$lang->dev->groupList['company'] = 'Doanh nghiệp';
$lang->dev->groupList['repo']    = 'CI';
$lang->dev->groupList['api']     = 'API';
$lang->dev->groupList['message'] = 'Tin nhắn';

$lang->dev->endGroupList['admin']  = 'Quản trị';
$lang->dev->endGroupList['system'] = 'Hệ thống';
$lang->dev->endGroupList['other']  = 'Khác';

==> ZenTaoALM.15.0.rc2.int.zip: zentaoalm/module/dev/lang/vi.php <==
<?php
$lang->dev->common     = 'Phát triển';
$lang->dev->api        = 'API';
$lang->dev->db         = 'Database';
$lang->dev->editor     = 'Editor';
$lang->dev->translate  = 'Translate';
$lang->dev->dbList     = 'Database';
$lang->dev->moduleList = 'Modules';
$lang->dev->params     = 'Thông số';
$lang->dev->type       = 'Loại';
$lang->dev->desc       = 'Mô tả';
$lang->dev->noParams   = 'Không có Parameters';
$lang->dev->post       = 'POST Parameter';

$lang->dev->paramRange    = 'Parameter Range: %s';
$lang->dev->paramDate     = 'Date format: YY-mm-dd, e.g 2019-01-01';
$lang->dev->paramColor    = 'Color format: #RGB, ví dụ:  #3da7f5';
$lang->dev->paramMailto   = "User account. Separate accounts by ','.";
$lang->dev->noteEditor    = "The editor is disabled for security reasons. To use this feature, please go to the official website to download and install the plugin of the <a href='https://www.zentao.pm/extension-viewExt-150.html' target='_blank'>editor</a>.";
$lang->dev->noteTranslate = "The translation is disabled for security reasons. To use this feature, please go to the official website to download and install the plugin of <a href='https://www.zentao.pm/extension-viewExt-151.html' target='_blank'>translation</a>.";

$lang->dev->fields = array();
$lang->dev->fields['id']     = 'ID';
$lang->dev->fields['name']   = 'Feild';
$lang->dev->fields['desc']   = 'Mô tả';
$lang->dev->fields['type']   = 'Loại';
$lang->dev->fields['length'] = 'Chiều dài';
$lang->dev->fields['null']   = 'Null';

$lang->dev->tableList = array();
$lang->dev->tableList['action']           = 'Hành động';
$lang->dev->tableList['bug']              = 'Bug';
$lang->dev->tableList['build']            = 'Bản dựng';
$lang->dev->tableList['burn']             = 'Burndown Chart';
$lang->dev->tableList['case']             = 'tình huống';
$lang->dev->tableList['casestep']         = 'Case bước';
$lang->dev->tableList['company']          = 'Doanh nghiệp';
$lang->dev->tableList['config']           = 'Cấu hình';
$lang->dev->tableList['custom']           = 'Tùy biến';
$lang->dev->tableList['dept']             = 'Phòng/Ban';
$lang->dev->tableList['doc']              = 'Tài liệu';
$lang->dev->tableList['doclib']           = 'Thư viện tài liệu';
$lang->dev->tableList['effort']           = 'Chấm công';
$lang->dev->tableList['extension']        = 'Extension';
$lang->dev->tableList['file']             = 'File';
$lang->dev->tableList['group']            = 'Nhóm';
$lang->dev->tableList['grouppriv']        = 'Phân quyền';
$lang->dev->tableList['history']          = 'Lịch sử';
$lang->dev->tableList['lang']             = 'Ngôn ngữ';
$lang->dev->tableList['module']           = 'Module';
$lang->dev->tableList['product']          = $lang->productCommon;
$lang->dev->tableList['productplan']      = 'Kế hoạch '.$lang->productCommon;
$lang->dev->tableList['project']          = 'project';
$lang->dev->tableList['projectproduct']   = 'project' . $lang->productCommon;
$lang->dev->tableList['projectstory']     = 'project Câu chuyện';
$lang->dev->tableList['execution']        = $lang->executionCommon;
$lang->dev->tableList['release']          = 'Phát hành';
$lang->dev->tableList['story']            = 'Câu chuyện';
$lang->dev->tableList['storyspec']        = 'Mô tả câu chuyện';
$lang->dev->tableList['task']             = 'Nhiệm vụ';
$lang->dev->tableList['taskestimate']     = 'Dự tính';
$lang->dev->tableList['team']             = 'Đội nhóm';
$lang->dev->tableList['testresult']       = 'Test kết quả';
$lang->dev->tableList['testrun']          = 'Test Run';
$lang->dev->tableList['testtask']         = 'Yêu cầu Test';
$lang->dev->tableList['todo']             = 'Việc làm';
$lang->dev->tableList['user']             = 'Người dùng';
$lang->dev->tableList['usercontact']      = 'Người dùng Liên hệ';
$lang->dev->tableList['usergroup']        = 'Người dùng Group';
$lang->dev->tableList['userquery']        = 'Người dùng truy vấn';
$lang->dev->tableList['usertpl']          = 'Người dùng mẫu';
$lang->dev->tableList['admin']            = 'Quản trị';
$lang->dev->tableList['api']              = 'API';
$lang->dev->tableList['backup']           = 'Sao lưu';
$lang->dev->tableList['common']           = 'Common';
$lang->dev->tableList['convert']          = 'Chuyển đổi';
$lang->dev->tableList['dev']              = 'Phát triển';
$lang->dev->tableList['git']              = 'GIT';
$lang->dev->tableList['index']            = 'Trang chủ';
$lang->dev->tableList['install']          = 'Cài đặt';
$lang->dev->tableList['mail']             = 'Email';
$lang->dev->tableList['misc']             = 'Khác';
$lang->dev->tableList['my']               = 'Dashboard';
$lang->dev->tableList['qa']               = 'QA';
$lang->dev->tableList['report']           = 'Báo cáo';
$lang->dev->tableList['search']           = 'Tìm kiếm';
$lang->dev->tableList['sso']              = 'SSO';
$lang->dev->tableList['svn']              = 'SVN';
$lang->dev->tableList['testcase']         = 'tình huống';
$lang->dev->tableList['testreport']       = 'Test báo cáo';
$lang->dev->tableList['testsuite']        = 'Test Suite';
$lang->dev->tableList['caselib']          = 'Case Library';
$lang->dev->tableList['tree']             = 'Module Tree';
$lang->dev->tableList['upgrade']          = 'Cập nhật';
$lang->dev->tableList['cron']             = 'Cron';
$lang->dev->tableList['datatable']        = 'Dữ liệu bảng';
$lang->dev->tableList['block']            = 'Block';
$lang->dev->tableList['branch']           = 'Nhánh';
$lang->dev->tableList['doccontent']       = 'Doc Content';
$lang->dev->tableList['storystage']       = 'Giai đoạn câu chuyện';
$lang->dev->tableList['tutorial']         = 'Hướng dẫn';
$lang->dev->tableList['suitecase']        = 'Suite tình huống';
$lang->dev->tableList['score']            = 'Điểm';
$lang->dev->tableList['entry']            = 'Application';
$lang->dev->tableList['webhook']          = 'WebHook';
$lang->dev->tableList['log']              = 'Nhật ký';
$lang->dev->tableList['message']          = 'Tin nhắn';
$lang->dev->tableList['notify']           = 'Thông báo';
$lang->dev->tableList['userview']         = 'Người dùng Privilege';
$lang->dev->tableList['repo']             = 'Mã';
$lang->dev->tableList['repohistory']      = 'Repo History';
$lang->dev->tableList['repofiles']        = 'Repo Files';
$lang->dev->tableList['repobranch']       = 'Repo nhánh';
$lang->dev->tableList['ci']               = 'CI';
$lang->dev->tableList['compile']          = 'Compile';
$lang->dev->tableList['jenkins']          = 'Jenkins';
$lang->dev->tableList['job']              = 'Job';
$lang->dev->tableList['searchdict']       = 'Search dict';
$lang->dev->tableList['searchindex']      = 'Search index';

$lang->dev->groupList['my']        = 'Dashboard';
$lang->dev->groupList['program']   = 'Program';
$lang->dev->groupList['product']   = $lang->productCommon;
$lang->dev->groupList['project']   = $lang->projectCommon;
$lang->dev->groupList['execution'] = $lang->executionCommon;
$lang->dev->groupList['qa']        = 'QA';
$lang->dev->groupList['doc']       = 'Tài liệu';
$lang->dev->groupList['report']    = 'Báo cáo';
$lang->dev->groupList['company']   = 'Doanh nghiệp';
$lang->dev->groupList['repo']      = 'CI';
$lang->dev->groupList['api']       = 'API';
$lang->dev->groupList['message']   = 'Tin nhắn';
$lang->dev->groupList['search']    = 'Tìm kiếm';

$lang->dev->endGroupList['admin']  = 'Quản trị';
$lang->dev->endGroupList['system'] = 'Hệ thống';
$lang->dev->endGroupList['other']  = 'Khác';
